
import javax.measure.unit.Unit;


/**
 * A container for plot definition data.
 * 
 * <p> Modified by: Joseph A. Huwaldt </p>
 * 
 * @author Joseph A. Huwaldt Date: September 3, 2011
 * @version March 8, 2017
 */
public class PlotDefinition {

    /**
     * The title of the plot.
     */
    public String title;
    
    /**
     * The independent variable name.
     */
    public String independentName;
    
    /**
     * The independent variable description.
     */
    public String independentDesc;
    
    /**
     * The dependent variable name.
     */
    public String dependentName;
    
    /**
     * The dependent variable description.
     */
    public String dependentDesc;
    
    /**
     * The independent variable source units.  This is ignored if the input file
     * has units defined.
     */
    public Unit independentSrcUnit;
    
    /**
     * The independent variable units for plotting.  This must be consistent with the source units.
     */
    public Unit independentPlotUnit;
    
    /**
     * The dependent variable source units.  This is ignored if the input file
     * has units defined.
     */
    public Unit dependentSrcUnit;
    
    /**
     * The dependent variable units for plotting.  This must be consistent with the source units.
     */
    public Unit dependentPlotUnit;
    

    /**
     * Creates a new instance of a PlotDefinition that defines the contents of a single
     * plot.
     *
     * @param title          The title of the plot.
     * @param indepName      The name of the independent variable.
     * @param indepDesc      A description of the independent variable.
     * @param depName        The name of the dependent variable.
     * @param depDesc        A description of the dependent variable.
     * @param indepSrcUnits  The source units for the independent variable.
     * @param indepDestUnits The destination units for the independent variable.
     * @param depSrcUnits    The source units for the dependent variable.
     * @param depDestUnits   The destination units for the dependent variable.
     */
    public PlotDefinition(String title, String indepName, String indepDesc, String depName, String depDesc,
            Unit indepSrcUnits, Unit indepDestUnits, Unit depSrcUnits, Unit depDestUnits) {
        this.title = title;
        independentName = indepName;
        independentDesc = indepDesc;
        dependentName = depName;
        dependentDesc = depDesc;
        independentSrcUnit = indepSrcUnits;
        independentPlotUnit = indepDestUnits;
        dependentSrcUnit = depSrcUnits;
        dependentPlotUnit = depDestUnits;
    }

    /**
     * Return a brief description of this plot definition in HTML format suitable for
     * display in a label or list cell.
     * 
     * @return A brief description of this plot definition in HTML format.
     */
    public String getListLabel() {
        StringBuilder buf = new StringBuilder();
        buf.append("<html><center>");
        buf.append(dependentName);
        buf.append("<br>vs.<br>");
        buf.append(independentName);
        buf.append("</center></html>");
        return buf.toString();
    }
}
