/*
 *  Angular Momentum  -- The quantify of angular momentum.
 *
 *  Copyright (C) 2017-2018, Joseph A. Huwaldt.
 *  All rights reserved.
 *
 *  This program is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU General Public License
 *  as published by the Free Software Foundation; either version 2
 *  of the License, or (at your option) any later version.
 *  
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 *  Or visit:  http://www.gnu.org/licenses/gpl.html
 */
package jahuwaldt.js.unit;

import javax.measure.quantity.Quantity;
import javax.measure.unit.SI;
import javax.measure.unit.Unit;

/**
 * This interface represents the quantity of angular momentum.
 * The system unit for this quantity is "kg*m^2/sec" (kilogram meter squared per second).
 *
 * <p> Modified by: Joseph A. Huwaldt </p>
 *
 * @author Joseph A. Huwaldt, Date: July 31, 2017
 * @version August 3, 2018
 */
public interface AngularMomentum extends Quantity {

    /**
     * Holds the SI unit (Système International d'Unités) for this quantity.
     */
    @SuppressWarnings("unchecked")
    public final static Unit<AngularMomentum> UNIT 
       = (Unit<AngularMomentum>) SI.KILOGRAM.times(SI.METER.pow(2).divide(SI.SECOND));

}