/**
*   Please feel free to use any fragment of the code in this file that you need
*   in your own work. As far as I am concerned, it's in the public domain. No
*   permission is necessary or required. Credit is always appreciated if you
*   use a large chunk or base a significant product on one of my examples,
*   but that's not required either.
*
*   This code is distributed in the hope that it will be useful,
*   but WITHOUT ANY WARRANTY; without even the implied warranty of
*   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
*
*      --- Joseph A. Huwaldt
**/
package jahuwaldt.swing;

import javax.swing.JFrame;
import javax.swing.JScrollPane;
import javax.swing.JTextArea;
import java.io.OutputStream;
import java.io.PrintWriter;

/**
*  A window that displays a text area that can be written
*  to using an OutputStream.
*
*  <p>  Modified by:  Joseph A. Huwaldt    </p>
*
*  @author    Joseph A. Huwaldt    Date:  March 15, 2003
*  @version   September 16, 2012
**/
@SuppressWarnings("serial")
public class StreamedTextViewer extends JFrame {

    private JStreamedTextArea textArea = new JStreamedTextArea();

	/**
	*  Construct a streamed text area window with the specified title.
	**/
    public StreamedTextViewer(String title) {
        super(title);
        textArea.setEditable(false);
		textArea.setDragEnabled(true);
		JScrollPane scrollPane = new JScrollPane(textArea);
		scrollPane.setVerticalScrollBarPolicy(JScrollPane.VERTICAL_SCROLLBAR_ALWAYS);
		scrollPane.setHorizontalScrollBarPolicy(JScrollPane.HORIZONTAL_SCROLLBAR_ALWAYS);
        getContentPane().add(scrollPane);
    }

	/**
	*  Return an output stream to the text area in this frame.  Text
	*  streamed to this output stream will be displayed in this frame.
	**/
	public OutputStream getOutputStream() {
		return textArea.getOutputStream();
	}
	
	/**
	*  Return the text area used to display the output stream.
	**/
	public JTextArea getTextArea() {
		return textArea;
	}
	
    public static void main(String[] args) {
        StreamedTextViewer frame = new StreamedTextViewer("Test");
		OutputStream stream = frame.getOutputStream();
		
		PrintWriter writer = new PrintWriter(stream, true);
		writer.println("This life is a test.  This life is only a test.");
		writer.println("If this had been a real life, you would have been");
		writer.println("told where to go and what to do.");
		
        frame.setDefaultCloseOperation(JFrame.EXIT_ON_CLOSE);
        frame.setVisible(true);
    }
}





